subroutine readout_sbs
!! Subroutine, which extracts data from basins.sbs file
!! Copyright (C) 2004  Thorsten Pohlert
!!
!! This program is free software; you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation; either version 2 of the License, or
!! (at your option) any later version.
!!
!! You should have received a copy of the GNU General Public License
!! along with this program; if not, write to the Free Software
!! Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
!!
!! VARIABLES
!! ---------
!! aa             LOGICAL                Test, whether file exists
!!
!! i, j, k, l     INTEGER                Counters
!! rch                                   Reach / Subbasin
!! hru                                   HRU
!! mon                                   Daily / monthly index
!! eof                                   End-of-file variable
!! yesno                                 YES = 1, NO = 2
!! mxhru                                 Maximum number of HRU's
!! hrusel                                Selected HRU
!!
!! maxval         INTEGER,PARAMETER      Maximum Nr. of variables in file to be extracted
!!
!! sum            REAL                   Counter of lines in file
!! size                                  Array size
!! mxsum                                 End of infinite do-loop
!!
!! head           CHARACTER(:)           Array containing the names of the variables in
!!                                       the file header
!!
!! yy             REAL(:)                'Moving-window' to read in the selected variable
!!
!! p_yy           REAL,POINTER           Points to selected output variable
!!
!! INTRINSICS
!! ---------
!! INT, REAL, MAX
!!
use globals
implicit none

logical:: aa
integer:: i, j, k, l, rch, hru, mxhru
integer:: eof, choice, yesno, hrusel, mon
real:: sum, size, mxsum
integer,parameter:: maxval = 58
character(len=10),dimension(maxval):: head
real,dimension(maxval),target:: yy
real,pointer:: p_yy

! See, whether file exists
inquire(file='basins.sbs',exist=aa)
  if (aa == .false.) then
     write(*,*) 'ERROR: basins.sbs does not exist!'
     write(*,*) 'Check, if you are in the correct directory!'
     write(*,*)
     write(*,*) 'READOUT exits without success!' 
     stop
  end if

! Open file
open(10,file='basins.sbs',status='old')

! Dialog:
write(*,*)
write(*,1000) 'READOUT BASINS.SBS: HRU Output File'
write(*,*)
write(*,1000) 'Please enter the number of the HRU you want to extract within the subbasin!'
write(*,*)
read(*,1001) hrusel

! Some more questions
do !Inner loop
  do !Outer loop
    write(*,*)
    write(*,1000) 'Please select the variable by entering its number!'
    write(*,*)
!! Print the variables to the screen and read users selection
    if (flag3 == 0) then
      j = 0
      k = 0
      do i = 1, 14
         j = i + 14
         k = i + 28
         l = i + 42
        write(*,3000) sbsvar(i), i, sbsvar(j), j, sbsvar(k), k, sbsvar(l), l
3000    format(a, 1X, i2, 2X, a, 1X, i2, 2X, a, 1X, i2, 2X, a, 1X, i2)
      end do
        write(*,3001) sbsvar(57), '57', sbsvar(58), '58'
3001    format(a, 1X, a, 2X, a, 1X ,a)

    else
      write(*,1000) '!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!'
      write(*,1000) 'CAUTION: You have customized your basins.cod!'
      write(*,1000) 'Check careful, whether READOUT returns you'
      write(*,1000) 'the correct variable!'
      write (*,*)
      do i = 1, nr3
        write(*, 5000) sbsvar(sbsfla(i)), i
5000    format(a, 1X, i2)
      end do
    end if
    read(*,1001) value

! Test the selection
      if(value < 1 .or. value > maxval) then
        write(*,*)
        write(*,1003) 'ERROR: you choose', value, ', which does not exist!'
        write(*,1000) 'Please repeat or QUIT READOUT with CRT-C!'
        write(*,*)
        cycle
      else
        exit
      end if
  end do
  
! Read input-file and skip the first 8 rows
  do i = 1, 8
    read(10,*)
  end do

! Read Header of columns (line 9)
  read(10,1005) (head(i), i = 1, maxval)

  write(*,*)
  write(*,1004) 'You selected ', head(value)
  write(*,1000) 'Is this correct?'
  write(*,*)
  write(*,1000) 'Yes                      1'
  write(*,1000) 'No                       2'
  read(*,1001) yesno
    if (yesno .ne. 1) then
      write(*,*)
      write(*,1000) 'Please change your selection!'
      rewind(10) !Go to first row of file
      cycle
    else
      exit ! Leave infinite loop
    end if
end do

! Get the Nr of rows and array size
write(*,*)
write(*,1000) 'Allocate memory! Please wait ...!'
i = 0
sum = 0.0
eof = 0
do while (eof == 0)
  read(10,1006,iostat=eof) mxhru
    sum = sum + 1.0
    mxhru = max(mxhru, i)
end do
!!
!Check wether selected HRU existst!
if (hrusel > mxhru) then
   write(*,*)
   write(*,1000) 'ERROR: Your selected HRU does not exist!'
   write(*,1003) 'There are', mxhru, '  HRUs in your project!'
   write(*,*)
   write(*,1000) 'Please run READOUT again!'
   write(*,1000) 'READOUT exits without success!'
   stop
end if

! Adjust sum and allocate arrays!
 mxsum = sum - 2.0
 size = 1.0 + mxsum / real(mxhru)
 asize = int(size)

  allocate (xx(asize), amon(asize))

! Now Re-open and read in the data
write(*,1000) 'Reading data from basins.sbs ...'

!rewind the file
rewind(10)
do i = 1, 9 
  read(10,*)
end do
! Read until the rest of the file
  p_yy => yy(value)
  j = 0
  sum = 0.
  do
    read(10,1008) hru, mon, (yy(k), k = 1, maxval)
      sum = sum + 1.0
      if (sum == mxsum) then
        exit
      end if
      if (hru == hrusel .and. mon <= 366) then
        j = j + 1
        xx(j) = p_yy
        amon(j) = mon
      end if
  end do

!Give actual information about records
rec = j

!Close the file
close(10)

! Write output results!
call write_sbs (head)


1000 format(a)
1001 format(i3)
1003 format(a, 1X, i3, a)
1004 format(a,a)
!                header
1005 format(43X, 58a10)
!               hru      rch
1006 format(4X, i4)!, 11X, i4)
!               hru             mon      data
1008 format(4X, i4, 9X, 5X, 5X, i5, 11X, 58f10.3)

end subroutine
