subroutine write_sbs (head)
!! Subroutine, which writes extracted data from basins.sbs file to disc
!! Copyright (C) 2004  Thorsten Pohlert
!!
!! This program is free software; you can redistribute it and/or modify
!! it under the terms of the GNU General Public License as published by
!! the Free Software Foundation; either version 2 of the License, or
!! (at your option) any later version.
!!
!! You should have received a copy of the GNU General Public License
!! along with this program; if not, write to the Free Software
!! Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
!! VARIABLES
!! ---------
!! yesno         INTEGER                YES = 1, NO = 2
!! formid                               Print out format specifier
!! i, k, l                              Counters
!!   
!! com            INTEGER,PARAMETER     "COMMA" specifier
!! sem                                  "SEMICOLON" specifier
!! gnu                                  "GNUPLOT FOMAT" specifier
!! R                                    "R FORMAT" specifier
!! maxval                               Maximum Nr. of variables in file to be extracted
!!
!! output         CHARACTER             Name of output file
!!
!! head           CHARACTER(:)           Array containing the names of the variables in
!!                                       the file header

use globals
implicit none
integer:: yesno, formid, i, k, l
integer,parameter:: com = 1, sem = 2, gnu = 3, R = 4

character(len=20):: output

integer,parameter:: maxval = 15
character(len=10),dimension(15):: head

do
  write(*,*)
  write(*,1000) 'Please enter a name for the outputfile (max. 20 chars.)!'

  write(*,1000) 'CAUTION: Existing file will be overwritten!'
  read(*,1000) output

  write(*,*)
  write(*,1001) 'You wrote ', output
  write(*,1000) 'Is this correct?'
  write(*,*)
  write(*,1000) 'Yes                  1'
  write(*,1000) 'No                   2'
  read(*,1002) yesno
! Check
   if (yesno .ne. 1) then
     write(*,1000) 'ERROR: Wrong selection!'
     write(*,1000) 'Try once more:'
     cycle
   else
     exit
   end if
end do

open(11,file=output,status='unknown')

do
  write(*,*)
  write(*,1000) 'Which output-format do you prefer?'
  write(*,*)
  write(*,*)
  write(*,1000) 'Comma "," delimited      (good for spreadsheets)    1'
  write(*,1000) 'Semicolon ";" delimited  (good for spreadsheets)    2'
  write(*,1000) 'formatted                (good for gnuplot)         3'
  write(*,1000) 'R format                 (good for R)               4'

  read (*,1002) formid
! Check
   if (formid > 4) then
     write(*,*)
     write(*,1000) 'ERROR: you selection does not exist!'
     write(*,1000) 'Please repeat or exit READOUT with CRT-C!'
     cycle
   else
     exit
   end if
end do

!Now let's go for output
if (formid == com) then
    write(11,*) '"NR"',',','"MON"',',','"',head(value),'"'
      do i = 1, rec
        write(11,1004) i, amon(i), xx(i)
      end do

  else if(formid == sem) then
    write(11,*) '"NR"',';','"MON"',';','"',head(value),'"'
      do i = 1, rec
        write(11,1005) i, amon(i), xx(i)
      end do

  else if(formid == gnu) then
    write(11,*) '    NR',' MON', head(value)
      do i = 1, rec
        write(11,1003) i, amon(i), xx(i)
      end do

  else if(formid == R) then
    write(11,1007) '"MON"',' "',head(value),'"'
      do i = 1, rec
        write(11,1006) i, amon(i),xx(i)
      end do
end if
close(11)

deallocate (amon, xx)

write(*,*)
write(*,1001) 'Data were written to ', output
write(*,*)

1000 format(a)
1001 format(a,a)
1002 format(i2)
1003 format(i6, i4, f10.3)
1004 format(i6.6,',',i3.3,',',f10.3)
1005 format(i6.6,';',i3.3,';',f10.3)
1006 format('"',i6.6,'"',1X, i3.3, f10.3)
1007 format(a,a,a10,a)
end subroutine
